==> mastapy-14.0.0b1.tar.gz: mastapy-14.0.0b1/mastapy/_private/utility/units_and_measurements/measurements/_1749.py <==
"""PressureVelocityProduct"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.utility.units_and_measurements import _1652
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_PRESSURE_VELOCITY_PRODUCT = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "PressureVelocityProduct"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="PressureVelocityProduct")
    CastSelf = TypeVar(
        "CastSelf", bound="PressureVelocityProduct._Cast_PressureVelocityProduct"
    )


__docformat__ = "restructuredtext en"
__all__ = ("PressureVelocityProduct",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PressureVelocityProduct:
    """Special nested class for casting PressureVelocityProduct to subclasses."""

    __parent__: "PressureVelocityProduct"

    @property
    def measurement_base(self: "CastSelf") -> "_1652.MeasurementBase":
        return self.__parent__._cast(_1652.MeasurementBase)

    @property
    def pressure_velocity_product(self: "CastSelf") -> "PressureVelocityProduct":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class PressureVelocityProduct(_1652.MeasurementBase):
    """PressureVelocityProduct

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PRESSURE_VELOCITY_PRODUCT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_PressureVelocityProduct":
        """Cast to another type.

        Returns:
            _Cast_PressureVelocityProduct
        """
        return _Cast_PressureVelocityProduct(self)

==> mastapy-14.1.0b2.tar.gz: mastapy-14.1.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1749.py <==
"""Number"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1666

_NUMBER = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Number"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Number")
    CastSelf = TypeVar("CastSelf", bound="Number._Cast_Number")


__docformat__ = "restructuredtext en"
__all__ = ("Number",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Number:
    """Special nested class for casting Number to subclasses."""

    __parent__: "Number"

    @property
    def measurement_base(self: "CastSelf") -> "_1666.MeasurementBase":
        return self.__parent__._cast(_1666.MeasurementBase)

    @property
    def number(self: "CastSelf") -> "Number":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Number(_1666.MeasurementBase):
    """Number

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _NUMBER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Number":
        """Cast to another type.

        Returns:
            _Cast_Number
        """
        return _Cast_Number(self)
